==> Transmission-0.6.1.tar.gz: Transmission-0.6.1/macosx/TorrentTableView.h <==
/******************************************************************************
 * $Id: TorrentTableView.h 381 2006-06-16 03:13:58Z livings124 $
 *
 * Copyright (c) 2005-2006 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import <transmission.h>

#define BUTTONS_TOTAL_WIDTH 42.0

@class Controller;

@interface TorrentTableView : NSTableView

{
    IBOutlet Controller * fController;
    NSArray             * fTorrents;

    NSPoint               fClickPoint;
    
    IBOutlet NSMenu     * fContextRow, * fContextNoRow;
    
    NSImage             * fResumeOnIcon, * fResumeOffIcon, * fPauseOnIcon, * fPauseOffIcon,
                        * fRevealOnIcon, * fRevealOffIcon;
}
- (void) setTorrents: (NSArray *) torrents;

@end

==> Transmission-0.82.tar.gz: Transmission-0.82/macosx/TorrentTableView.h <==
/******************************************************************************
 * $Id: TorrentTableView.h 1645 2007-04-03 02:22:25Z livings124 $
 *
 * Copyright (c) 2005-2007 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import <transmission.h>

#define BUTTONS_TOTAL_WIDTH 39.0

@class Controller;

@interface TorrentTableView : NSTableView

{
    IBOutlet Controller * fController;
    NSArray             * fTorrents;
    NSPoint             fClickPoint;
    
    NSUserDefaults      * fDefaults;
    
    IBOutlet NSMenu     * fContextRow, * fContextNoRow;
    NSImage             * fResumeOnIcon, * fResumeOffIcon,
                        * fPauseOnIcon, * fPauseOffIcon,
                        * fResumeNoWaitOnIcon, * fResumeNoWaitOffIcon, 
                        * fRevealOnIcon, * fRevealOffIcon;
    
    NSMutableArray      * fKeyStrokes;
    
    NSDictionary        * fSmallStatusAttributes;
}
- (void) setTorrents: (NSArray *) torrents;

@end
